@@ -1,7 +1,7 @@
-# This file is part of the Minnesota Population Center's ipumsr.
+# This file is part of the ipumsr R package created by IPUMS.
 # For copyright and licensing information, see the NOTICE and LICENSE files
 # in this project's top-level directory, and also on-line at:
-#   https://github.com/mnpopcenter/ipumsr
+#   https://github.com/ipums/ipumsr
 
 #' Set labelled values to missing
 #'
@@ -402,37 +402,6 @@ abort_coercion_function <- function(x) {
   abort(paste0("Can't convert ", x_type, " to function"))
 }
 
-# Copied from rlang:::friendly_type_of()
-friendly_type_of <- function(x, length = FALSE) {
-  if (is.object(x)) {
-    return(sprintf("a `%s` object", paste(class(x),
-                                          collapse = "/")))
-  }
-  friendly <- as_friendly_type(typeof(x))
-  if (length && rlang::is_vector(x)) {
-    friendly <- paste0(friendly, sprintf(" of length %s",
-                                         length(x)))
-  }
-  friendly
-}
-
-# Copied from rlang:::as_friendly_type()
-as_friendly_type <- function(type) {
-  switch(type, logical = "a logical vector", integer = "an integer vector",
-         numeric = , double = "a double vector", complex = "a complex vector",
-         character = "a character vector", raw = "a raw vector",
-         string = "a string", list = "a list", `NULL` = "NULL",
-         environment = "an environment", externalptr = "a pointer",
-         weakref = "a weak reference", S4 = "an S4 object",
-         name = , symbol = "a symbol", language = "a call",
-         pairlist = "a pairlist node", expression = "an expression vector",
-         quosure = "a quosure", formula = "a formula",
-         char = "an internal string", promise = "an internal promise",
-         ... = "an internal dots object", any = "an internal `any` object",
-         bytecode = "an internal bytecode object", primitive = ,
-         builtin = , special = "a primitive function", closure = "a function",
-         type)
-}
 
 #' Make a label placeholder object
 #'
@@ -483,7 +452,7 @@ lbl <- function(...) {
 }
 
 fill_in_lbl <- function(lblval, orig_labels) {
-  if (class(lblval) != "lbl_placeholder") lblval <- lbl(.val = lblval)
+  if (!inherits(lblval, "lbl_placeholder")) lblval <- lbl(.val = lblval)
   if (is.null(lblval$.lbl) & is.null(lblval$.val)) {
     stop("Could not fill in label because neither label nor value is specified")
   }
